# PMCLI

## A password encrypter and decrypter

## Install

#### Windows

pip install pmcli 

### How to use

#### Windows
Open powershell and type pm

Encrypting 

Open Powershell and type pm. 
Then type pm encrypt
Then it will ask for a directory. 
Give the directory with the file.txt
Note: You don't have to make a file it makes on itself
It will add the file with the encrypted file

Decrypting
Open Powershell and type pm. 
Then type pm decrypt
Then it will ask for a directory. 
Give the directory with the file.txt
Then it will display the decrypted text


### Softwares used

Visual Studio Code - https://github.com/Microsoft/vscode

Python 3.9.1

